@@ -1,15 +1,12 @@
-# pyre-strict
-
-from typing import Type, Tuple, Any
+from typing import Any, Tuple, Type
 
 try:
     # python 3.8 and above
-    from plistlib import UID
+    from plistlib import UID  # type: ignore
 except ImportError:
     # python 3.7 and below
-    class UID:
+    class UID:  # type: ignore
         def __init__(self, data: int) -> None:
-            # pyre-ignore
             if not isinstance(data, int):
                 raise TypeError("data must be an int")
             if data >= 1 << 64:
@@ -25,7 +22,7 @@ except ImportError:
             return "%s(%s)" % (self.__class__.__name__, repr(self.data))
 
         def __reduce__(self) -> Tuple[Type["UID"], Tuple[int]]:
-            return self.__class__, (self.data,)
+            return self.__class__, (self.data,)  # type: ignore
 
         def __eq__(self, other: Any) -> bool:  # pyre-ignore[2]
             if not isinstance(other, UID):
